CCL: IntMagPar Struct Reference

CCL

Data Fields
IntMagPar Struct Reference

## Data Fields
double | chi
SplPar * | spl_pz
SplPar * | spl_sz
ccl_cosmology * | cosmo
int * | status

## Field Documentation

## ◆ chi

double IntMagPar::chi

## ◆ cosmo

ccl_cosmology* IntMagPar::cosmo

## ◆ spl_pz

SplPar* IntMagPar::spl_pz

## ◆ spl_sz

SplPar* IntMagPar::spl_sz

## ◆ status

int* IntMagPar::status

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_cls.c